==> infima_client-0.282.1.tar.gz: infima_client-0.282.1/src/infima_client/core/models/cohort/v1/check_coverage_request.py <==
from typing import (
    Any,
    BinaryIO,
    Dict,
    List,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
    Union,
    cast,
)

from attr import define, field

from infima_client.core.types import UNSET, Unset

T = TypeVar("T", bound="CohortV1CheckCoverageRequest")


@define(auto_attribs=True)
class CohortV1CheckCoverageRequest:
    """
    Attributes:
        cohorts (Union[Unset, List[str]]): Cohorts to check coverage. Example: FNCL 2.0 2021.
    """

    cohorts: Union[Unset, List[str]] = UNSET
    additional_properties: Dict[str, Any] = field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        cohorts: Union[Unset, List[str]] = UNSET
        if not isinstance(self.cohorts, Unset):
            cohorts = self.cohorts

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cohorts is not UNSET:
            field_dict["cohorts"] = cohorts

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        cohorts = cast(List[str], d.pop("cohorts", UNSET))

        cohort_v1_check_coverage_request = cls(
            cohorts=cohorts,
        )

        cohort_v1_check_coverage_request.additional_properties = d
        return cohort_v1_check_coverage_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> infima_client-0.283.2.tar.gz: infima_client-0.283.2/src/infima_client/core/models/cohort/v1/check_coverage_request.py <==
from typing import (
    Any,
    BinaryIO,
    Dict,
    List,
    Optional,
    TextIO,
    Tuple,
    Type,
    TypeVar,
    cast,
)

from attr import define, field

from infima_client.core.types import UNSET, Unset

T = TypeVar("T", bound="CohortV1CheckCoverageRequest")


@define(auto_attribs=True)
class CohortV1CheckCoverageRequest:
    """
    Attributes:
        cohorts (List[str]): Cohorts to check coverage. Example: FNCL 2.0 2021.
    """

    cohorts: List[str]
    additional_properties: Dict[str, Any] = field(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        cohorts = self.cohorts

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update(
            {
                "cohorts": cohorts,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        cohorts = cast(List[str], d.pop("cohorts"))

        cohort_v1_check_coverage_request = cls(
            cohorts=cohorts,
        )

        cohort_v1_check_coverage_request.additional_properties = d
        return cohort_v1_check_coverage_request

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
